# Handlematters

Self-contained template system with Handlebars and inline shell scripts

## Introduction

Handlematters is a template system that combines Handlebars and shell scripts. It is intended to replace simple substitution tasks such as those done by envsubst.

Here is an example of a Handlematters template:

```
hello.hms

Any text before the context or template block is just a comment.
It will not be output.

--- context ---
greeting: echo 'hello, world'
count: |
  echo -n 'hello, world' | wc --chars

--- template ---
{{greeting}} (length: {{count}})
```

Passing this file to handlematters will result in the following output:

```
$ handlematters hello.hms
hello, world (length: 12)
```

Let's take a closer look.

```
--- context ---
greeting: echo 'hello, world'
count: |
  echo -n 'hello, world' | wc --chars
```

The `context` block is a YAML document. Each value of the property will be executed as a shell script and the output will be the resulting value.

```
--- template ---
{{greeting}} (length: {{count}})
```

The `template` block is a Handlebars template. `{{...}}` to output the context value. If you are not familiar with Handlebars syntax, have a look at https://handlebarsjs.com/.

Let's look at a more practical example:

```
Note: The expression in triplet braces {{{...}}} will be output without HTML escaping.

--- context ---
name: cargo metadata --format-version=1 --no-deps | jq -r .packages[0].name
author: cargo metadata --format-version=1 --no-deps | jq -r .packages[0].authors[0]

--- template ---
{{{name}}} by {{{author}}}
```

Will result in:

```
handlematters by Keita Urashima <ursm@ursm.jp>
```

Of course, this README is also generated by Handlematters. See: https://github.com/ursm/handlematters/blob/main/README.md.hms

## Usage

```
handlematters 0.1.0

Keita Urashima <ursm@ursm.jp>

Self-contained template system with Handlebars and inline shell scripts

USAGE:
    handlematters [FILE]

ARGS:
    <FILE>    Input file [default: stdin]

OPTIONS:
    -h, --help       Print help information
    -V, --version    Print version information
```
